from fastapi import FastAPI, responses
from src.backend.app.api.endpoints import router
from src.backend.app.utils.logger import setup_logging
from src.backend.config import settings

def create_app() -> FastAPI:
    # 设置日志
    setup_logging()

    # 创建FastAPI应用
    app = FastAPI(
        title=settings.APP_NAME,
        debug=settings.DEBUG,
        docs_url=f"{settings.API_PREFIX}/docs",
        redoc_url=f"{settings.API_PREFIX}/redoc",
        openapi_url=f"{settings.API_PREFIX}/openapi.json"
    )

    # 添加根路径重定向
    @app.get("/", include_in_schema=False)
    async def root():
        return responses.RedirectResponse(url=f"{settings.API_PREFIX}/docs")

    # 添加favicon处理
    @app.get("/favicon.ico", include_in_schema=False)
    async def favicon():
        return responses.Response(status_code=204)

    # 添加API路由
    app.include_router(router, prefix=settings.API_PREFIX)



    return app
app = create_app()